# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/translation/translation_table.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/translation/translation_table.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9protos/perfetto/trace/translation/translation_table.proto\x12\x0fperfetto.protos\"\xa7\x03\n\x10TranslationTable\x12M\n\x10\x63hrome_histogram\x18\x01 \x01(\x0b\x32\x31.perfetto.protos.ChromeHistorgramTranslationTableH\x00\x12M\n\x11\x63hrome_user_event\x18\x02 \x01(\x0b\x32\x30.perfetto.protos.ChromeUserEventTranslationTableH\x00\x12Y\n\x17\x63hrome_performance_mark\x18\x03 \x01(\x0b\x32\x36.perfetto.protos.ChromePerformanceMarkTranslationTableH\x00\x12@\n\nslice_name\x18\x04 \x01(\x0b\x32*.perfetto.protos.SliceNameTranslationTableH\x00\x12O\n\x12process_track_name\x18\x05 \x01(\x0b\x32\x31.perfetto.protos.ProcessTrackNameTranslationTableH\x00\x42\x07\n\x05table\"\xae\x01\n ChromeHistorgramTranslationTable\x12W\n\x0chash_to_name\x18\x01 \x03(\x0b\x32\x41.perfetto.protos.ChromeHistorgramTranslationTable.HashToNameEntry\x1a\x31\n\x0fHashToNameEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbf\x01\n\x1f\x43hromeUserEventTranslationTable\x12\x63\n\x13\x61\x63tion_hash_to_name\x18\x01 \x03(\x0b\x32\x46.perfetto.protos.ChromeUserEventTranslationTable.ActionHashToNameEntry\x1a\x37\n\x15\x41\x63tionHashToNameEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe3\x02\n%ChromePerformanceMarkTranslationTable\x12\x65\n\x11site_hash_to_name\x18\x01 \x03(\x0b\x32J.perfetto.protos.ChromePerformanceMarkTranslationTable.SiteHashToNameEntry\x12\x65\n\x11mark_hash_to_name\x18\x02 \x03(\x0b\x32J.perfetto.protos.ChromePerformanceMarkTranslationTable.MarkHashToNameEntry\x1a\x35\n\x13SiteHashToNameEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x35\n\x13MarkHashToNameEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc2\x01\n\x19SliceNameTranslationTable\x12g\n\x18raw_to_deobfuscated_name\x18\x01 \x03(\x0b\x32\x45.perfetto.protos.SliceNameTranslationTable.RawToDeobfuscatedNameEntry\x1a<\n\x1aRawToDeobfuscatedNameEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd0\x01\n ProcessTrackNameTranslationTable\x12n\n\x18raw_to_deobfuscated_name\x18\x01 \x03(\x0b\x32L.perfetto.protos.ProcessTrackNameTranslationTable.RawToDeobfuscatedNameEntry\x1a<\n\x1aRawToDeobfuscatedNameEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.translation.translation_table_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CHROMEHISTORGRAMTRANSLATIONTABLE_HASHTONAMEENTRY']._loaded_options = None
  _globals['_CHROMEHISTORGRAMTRANSLATIONTABLE_HASHTONAMEENTRY']._serialized_options = b'8\001'
  _globals['_CHROMEUSEREVENTTRANSLATIONTABLE_ACTIONHASHTONAMEENTRY']._loaded_options = None
  _globals['_CHROMEUSEREVENTTRANSLATIONTABLE_ACTIONHASHTONAMEENTRY']._serialized_options = b'8\001'
  _globals['_CHROMEPERFORMANCEMARKTRANSLATIONTABLE_SITEHASHTONAMEENTRY']._loaded_options = None
  _globals['_CHROMEPERFORMANCEMARKTRANSLATIONTABLE_SITEHASHTONAMEENTRY']._serialized_options = b'8\001'
  _globals['_CHROMEPERFORMANCEMARKTRANSLATIONTABLE_MARKHASHTONAMEENTRY']._loaded_options = None
  _globals['_CHROMEPERFORMANCEMARKTRANSLATIONTABLE_MARKHASHTONAMEENTRY']._serialized_options = b'8\001'
  _globals['_SLICENAMETRANSLATIONTABLE_RAWTODEOBFUSCATEDNAMEENTRY']._loaded_options = None
  _globals['_SLICENAMETRANSLATIONTABLE_RAWTODEOBFUSCATEDNAMEENTRY']._serialized_options = b'8\001'
  _globals['_PROCESSTRACKNAMETRANSLATIONTABLE_RAWTODEOBFUSCATEDNAMEENTRY']._loaded_options = None
  _globals['_PROCESSTRACKNAMETRANSLATIONTABLE_RAWTODEOBFUSCATEDNAMEENTRY']._serialized_options = b'8\001'
  _globals['_TRANSLATIONTABLE']._serialized_start=79
  _globals['_TRANSLATIONTABLE']._serialized_end=502
  _globals['_CHROMEHISTORGRAMTRANSLATIONTABLE']._serialized_start=505
  _globals['_CHROMEHISTORGRAMTRANSLATIONTABLE']._serialized_end=679
  _globals['_CHROMEHISTORGRAMTRANSLATIONTABLE_HASHTONAMEENTRY']._serialized_start=630
  _globals['_CHROMEHISTORGRAMTRANSLATIONTABLE_HASHTONAMEENTRY']._serialized_end=679
  _globals['_CHROMEUSEREVENTTRANSLATIONTABLE']._serialized_start=682
  _globals['_CHROMEUSEREVENTTRANSLATIONTABLE']._serialized_end=873
  _globals['_CHROMEUSEREVENTTRANSLATIONTABLE_ACTIONHASHTONAMEENTRY']._serialized_start=818
  _globals['_CHROMEUSEREVENTTRANSLATIONTABLE_ACTIONHASHTONAMEENTRY']._serialized_end=873
  _globals['_CHROMEPERFORMANCEMARKTRANSLATIONTABLE']._serialized_start=876
  _globals['_CHROMEPERFORMANCEMARKTRANSLATIONTABLE']._serialized_end=1231
  _globals['_CHROMEPERFORMANCEMARKTRANSLATIONTABLE_SITEHASHTONAMEENTRY']._serialized_start=1123
  _globals['_CHROMEPERFORMANCEMARKTRANSLATIONTABLE_SITEHASHTONAMEENTRY']._serialized_end=1176
  _globals['_CHROMEPERFORMANCEMARKTRANSLATIONTABLE_MARKHASHTONAMEENTRY']._serialized_start=1178
  _globals['_CHROMEPERFORMANCEMARKTRANSLATIONTABLE_MARKHASHTONAMEENTRY']._serialized_end=1231
  _globals['_SLICENAMETRANSLATIONTABLE']._serialized_start=1234
  _globals['_SLICENAMETRANSLATIONTABLE']._serialized_end=1428
  _globals['_SLICENAMETRANSLATIONTABLE_RAWTODEOBFUSCATEDNAMEENTRY']._serialized_start=1368
  _globals['_SLICENAMETRANSLATIONTABLE_RAWTODEOBFUSCATEDNAMEENTRY']._serialized_end=1428
  _globals['_PROCESSTRACKNAMETRANSLATIONTABLE']._serialized_start=1431
  _globals['_PROCESSTRACKNAMETRANSLATIONTABLE']._serialized_end=1639
  _globals['_PROCESSTRACKNAMETRANSLATIONTABLE_RAWTODEOBFUSCATEDNAMEENTRY']._serialized_start=1368
  _globals['_PROCESSTRACKNAMETRANSLATIONTABLE_RAWTODEOBFUSCATEDNAMEENTRY']._serialized_end=1428
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/power/android_entity_state_residency.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/power/android_entity_state_residency.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@protos/perfetto/trace/power/android_entity_state_residency.proto\x12\x0fperfetto.protos\"\xbb\x03\n\x14\x45ntityStateResidency\x12R\n\x12power_entity_state\x18\x01 \x03(\x0b\x32\x36.perfetto.protos.EntityStateResidency.PowerEntityState\x12G\n\tresidency\x18\x02 \x03(\x0b\x32\x34.perfetto.protos.EntityStateResidency.StateResidency\x1a\x66\n\x10PowerEntityState\x12\x14\n\x0c\x65ntity_index\x18\x01 \x01(\x05\x12\x13\n\x0bstate_index\x18\x02 \x01(\x05\x12\x13\n\x0b\x65ntity_name\x18\x03 \x01(\t\x12\x12\n\nstate_name\x18\x04 \x01(\t\x1a\x9d\x01\n\x0eStateResidency\x12\x14\n\x0c\x65ntity_index\x18\x01 \x01(\x05\x12\x13\n\x0bstate_index\x18\x02 \x01(\x05\x12\x1e\n\x16total_time_in_state_ms\x18\x03 \x01(\x04\x12\x1f\n\x17total_state_entry_count\x18\x04 \x01(\x04\x12\x1f\n\x17last_entry_timestamp_ms\x18\x05 \x01(\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.power.android_entity_state_residency_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ENTITYSTATERESIDENCY']._serialized_start=86
  _globals['_ENTITYSTATERESIDENCY']._serialized_end=529
  _globals['_ENTITYSTATERESIDENCY_POWERENTITYSTATE']._serialized_start=267
  _globals['_ENTITYSTATERESIDENCY_POWERENTITYSTATE']._serialized_end=369
  _globals['_ENTITYSTATERESIDENCY_STATERESIDENCY']._serialized_start=372
  _globals['_ENTITYSTATERESIDENCY_STATERESIDENCY']._serialized_end=529
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/trace.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/trace.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protos.perfetto.trace import trace_packet_pb2 as protos_dot_perfetto_dot_trace_dot_trace__packet__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!protos/perfetto/trace/trace.proto\x12\x0fperfetto.protos\x1a(protos/perfetto/trace/trace_packet.proto\"5\n\x05Trace\x12,\n\x06packet\x18\x01 \x03(\x0b\x32\x1c.perfetto.protos.TracePacket')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.trace_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TRACE']._serialized_start=96
  _globals['_TRACE']._serialized_end=149
# @@protoc_insertion_point(module_scope)



import pyarrow
import grpc
from google.protobuf import any_pb2
from . import Flight_pb2_grpc
from . import FlightSql_pb2_grpc
from . import FlightSql_pb2
from . import Flight_pb2
from . import arrow_flatbuffers
from . import arrow_ipc_reader
from . import time


def fb_time_unit_to_string(fb_time_unit):
    time_unit_enum = arrow_flatbuffers.TimeUnit
    if fb_time_unit == time_unit_enum.SECOND:
        return "s"
    if fb_time_unit == time_unit_enum.MILLISECOND:
        return "ms"
    if fb_time_unit == time_unit_enum.MICROSECOND:
        return "us"
    if fb_time_unit == time_unit_enum.NANOSECOND:
        return "ns"
    raise RuntimeError("unsupported time unit {}".format(fb_time_unit))


def fb_field_type_to_arrow(fb_field):
    fb_type = fb_field.TypeType()
    fb_type_enum = arrow_flatbuffers.Type
    assert fb_type != fb_type_enum.NONE
    if fb_type == fb_type_enum.Null:
        return pyarrow.null()
    elif fb_type == fb_type_enum.Int:
        type_int = arrow_flatbuffers.Int()
        field_type_table = fb_field.Type()
        type_int.Init(field_type_table.Bytes, field_type_table.Pos)
        if type_int.IsSigned():
            if type_int.BitWidth() == 8:
                return pyarrow.int8()
            elif type_int.BitWidth() == 16:
                return pyarrow.int16()
            elif type_int.BitWidth() == 32:
                return pyarrow.int32()
            elif type_int.BitWidth() == 64:
                return pyarrow.int64()
            else:
                raise RuntimeError(
                    "unsupported int size {}".format(type_int.BitWidth())
                )
        else:
            if type_int.BitWidth() == 8:
                return pyarrow.uint8()
            elif type_int.BitWidth() == 16:
                return pyarrow.uint16()
            elif type_int.BitWidth() == 32:
                return pyarrow.uint32()
            elif type_int.BitWidth() == 64:
                return pyarrow.uint64()
            else:
                raise RuntimeError(
                    "unsupported uint size {}".format(type_int.BitWidth())
                )
    elif fb_type == fb_type_enum.FloatingPoint:
        return pyarrow.float64()
    elif fb_type == fb_type_enum.Binary:
        return pyarrow.binary()
    elif fb_type == fb_type_enum.Utf8:
        return pyarrow.utf8()
    elif fb_type == fb_type_enum.Bool:
        return pyarrow.bool()
    elif fb_type == fb_type_enum.Timestamp:
        ts_type = arrow_flatbuffers.Timestamp()
        field_type_table = fb_field.Type()
        ts_type.Init(field_type_table.Bytes, field_type_table.Pos)
        return pyarrow.timestamp(
            fb_time_unit_to_string(ts_type.Unit()), ts_type.Timezone()
        )
    elif fb_type == fb_type_enum.List:
        assert 1 == fb_field.ChildrenLength()
        child_field = fb_field_to_arrow(fb_field.Children(0))
        return pyarrow.list_(child_field)
    elif fb_type == fb_type_enum.Struct_:
        struct_fields = []
        for child_index in range(fb_field.ChildrenLength()):
            child = fb_field_to_arrow(fb_field.Children(child_index))
            struct_fields.append(child)
        return pyarrow.struct(struct_fields)
    raise RuntimeError("unknown flatbuffer type {}".format(fb_type))


def fb_field_to_arrow(fb_field):
    arrow_type = fb_field_type_to_arrow(fb_field)
    return pyarrow.field(fb_field.Name(), arrow_type)


def make_query_flight_descriptor(sql):
    command_query = FlightSql_pb2.CommandStatementQuery(query=sql)
    any_cmd = any_pb2.Any()
    any_cmd.Pack(command_query)
    desc = Flight_pb2.FlightDescriptor()
    desc.type = Flight_pb2.FlightDescriptor.DescriptorType.CMD
    desc.cmd = any_cmd.SerializeToString()
    return desc


def read_schema_from_flight_data(flight_data):
    msg = arrow_flatbuffers.Message.GetRootAs(flight_data.data_header, 0)
    assert msg.Version() == arrow_flatbuffers.MetadataVersion.V5
    header = msg.Header()
    assert msg.HeaderType() == arrow_flatbuffers.MessageHeader.Schema

    schema = arrow_flatbuffers.Schema()
    schema.Init(header.Bytes, header.Pos)
    nb_fields = schema.FieldsLength()
    arrow_fields = []
    for x in range(nb_fields):
        field = schema.Fields(x)
        arrow_f = fb_field_to_arrow(field)
        arrow_fields.append(arrow_f)
    arrow_schema = pyarrow.schema(arrow_fields)
    return arrow_schema


def read_record_batch_from_flight_data(arrow_schema, flight_data):
    msg = arrow_flatbuffers.Message.GetRootAs(flight_data.data_header, 0)
    assert msg.HeaderType() == arrow_flatbuffers.MessageHeader.RecordBatch
    header = msg.Header()
    fb_record_batch = arrow_flatbuffers.RecordBatch()
    fb_record_batch.Init(header.Bytes, header.Pos)
    nodes = []
    for node_index in range(fb_record_batch.NodesLength()):
        node = fb_record_batch.Nodes(node_index)
        nodes.append(node)

    buffers = []
    for buffer_index in range(fb_record_batch.BuffersLength()):
        buffer = fb_record_batch.Buffers(buffer_index)
        buffers.append(buffer)

    body = pyarrow.py_buffer(flight_data.data_body)
    arrow_buffers = []
    for b in buffers:
        s = body.slice(b.Offset(), b.Length())
        arrow_buffers.append(s)
    rb = arrow_ipc_reader.read_record_batch(arrow_schema, nodes, arrow_buffers)
    return rb


def channel_creds_from_token(token):
    call_credentials = grpc.access_token_call_credentials(token)
    channel_cred = grpc.composite_channel_credentials(
        grpc.ssl_channel_credentials(), call_credentials
    )
    return channel_cred


class FlightSQLAuthMetadataPlugin(grpc.AuthMetadataPlugin):
    def __init__(self, headers):
        # we transform the keys into lowercase to avoid illegal grpc metadata (like 'Authorization', for example)
        self.__headers = [(k.lower(), v) for (k, v) in headers.items()]

    def __call__(self, context, callback):
        callback(self.__headers, None)


def channel_creds_from_headers(headers):
    auth_plugin = FlightSQLAuthMetadataPlugin(headers)
    call_credentials = grpc.metadata_call_credentials(auth_plugin)
    channel_cred = grpc.composite_channel_credentials(
        grpc.ssl_channel_credentials(), call_credentials
    )
    return channel_cred


class FlightSQLClient:
    def __init__(self, host_port, channel_creds):
        self.__host_port = host_port
        self.__channel_creds = channel_creds

    def make_channel(self):
        if self.__channel_creds is None:
            return grpc.insecure_channel(self.__host_port)
        else:
            return grpc.secure_channel(self.__host_port, self.__channel_creds)

    def query(self, sql, begin=None, end=None):
        metadata = []
        if begin is not None:
            metadata.append(("query_range_begin", time.format_datetime(begin)))
        if end is not None:
            metadata.append(("query_range_end", time.format_datetime(end)))

        channel = self.make_channel()
        stub = Flight_pb2_grpc.FlightServiceStub(channel)
        desc = make_query_flight_descriptor(sql)
        info = stub.GetFlightInfo(desc)
        grpc_rdv = stub.DoGet(info.endpoint[0].ticket, metadata=metadata)
        flight_data_list = list(grpc_rdv)
        if len(flight_data_list) < 1:
            raise RuntimeError("too few flightdata messages {}", len(flight_data_list))
        schema_message = flight_data_list[0]
        data_messages = flight_data_list[1:]
        schema = read_schema_from_flight_data(schema_message)
        record_batches = []
        for msg in data_messages:
            record_batches.append(read_record_batch_from_flight_data(schema, msg))
        table = pyarrow.Table.from_batches(record_batches, schema)
        return table.to_pandas()

    def query_stream(self, sql, begin=None, end=None):
        metadata = []
        if begin is not None:
            metadata.append(("query_range_begin", time.format_datetime(begin)))
        if end is not None:
            metadata.append(("query_range_end", time.format_datetime(end)))

        channel = self.make_channel()
        stub = Flight_pb2_grpc.FlightServiceStub(channel)
        desc = make_query_flight_descriptor(sql)
        info = stub.GetFlightInfo(desc)
        grpc_rdv = stub.DoGet(info.endpoint[0].ticket, metadata=metadata)
        schema_message = grpc_rdv.next()
        schema = read_schema_from_flight_data(schema_message)
        for msg in grpc_rdv:
            yield read_record_batch_from_flight_data(schema, msg)

    def retire_partitions(self, view_set_name, view_instance_id, begin, end):
        sql = """
          SELECT time, msg
          FROM retire_partitions('{view_set_name}', '{view_instance_id}', '{begin}', '{end}')
        """.format(
            view_set_name=view_set_name,
            view_instance_id=view_instance_id,
            begin=begin.isoformat(),
            end=end.isoformat(),
        )
        for rb in self.query_stream(sql):
            for index, row in rb.to_pandas().iterrows():
                print(row["time"], row["msg"])

    def materialize_partitions(
        self, view_set_name, begin, end, partition_delta_seconds
    ):
        sql = """
          SELECT time, msg
          FROM materialize_partitions('{view_set_name}', '{begin}', '{end}', {partition_delta_seconds})
        """.format(
            view_set_name=view_set_name,
            begin=begin.isoformat(),
            end=end.isoformat(),
            partition_delta_seconds=partition_delta_seconds,
        )
        for rb in self.query_stream(sql):
            for index, row in rb.to_pandas().iterrows():
                print(row["time"], row["msg"])

    def find_process(self, process_id):
        sql = """
            SELECT *
            FROM processes
            WHERE process_id='{process_id}';
            """.format(
            process_id=process_id
        )
        return self.query(sql)

    def query_streams(self, begin, end, limit, process_id=None, tag_filter=None):
        conditions = []
        if process_id is not None:
            conditions.append("process_id='{process_id}'".format(process_id=process_id))
        if tag_filter is not None:
            conditions.append(
                "(array_position(tags, '{tag}') is not NULL)".format(tag=tag_filter)
            )
        where = ""
        if len(conditions) > 0:
            where = "WHERE " + " AND ".join(conditions)
        sql = """
            SELECT *
            FROM streams
            {where}
            LIMIT {limit};
            """.format(
            where=where, limit=limit
        )
        return self.query(sql, begin, end)

    def query_blocks(self, begin, end, limit, stream_id):
        sql = """
            SELECT *
            FROM blocks
            WHERE stream_id='{stream_id}'
            LIMIT {limit};
            """.format(
                limit=limit,stream_id=stream_id
        )
        return self.query(sql, begin, end)

    def query_spans(self, begin, end, limit, stream_id):
        sql = """
            SELECT *
            FROM view_instance('thread_spans', '{stream_id}')
            LIMIT {limit};
            """.format(
                limit=limit,stream_id=stream_id
        )
        return self.query(sql, begin, end)
    



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/ftrace/v4l2.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/ftrace/v4l2.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'protos/perfetto/trace/ftrace/v4l2.proto\x12\x0fperfetto.protos\"\x9b\x03\n\x13V4l2QbufFtraceEvent\x12\x11\n\tbytesused\x18\x01 \x01(\r\x12\r\n\x05\x66ield\x18\x02 \x01(\r\x12\r\n\x05\x66lags\x18\x03 \x01(\r\x12\r\n\x05index\x18\x04 \x01(\r\x12\r\n\x05minor\x18\x05 \x01(\x05\x12\x10\n\x08sequence\x18\x06 \x01(\r\x12\x16\n\x0etimecode_flags\x18\x07 \x01(\r\x12\x17\n\x0ftimecode_frames\x18\x08 \x01(\r\x12\x16\n\x0etimecode_hours\x18\t \x01(\r\x12\x18\n\x10timecode_minutes\x18\n \x01(\r\x12\x18\n\x10timecode_seconds\x18\x0b \x01(\r\x12\x15\n\rtimecode_type\x18\x0c \x01(\r\x12\x1a\n\x12timecode_userbits0\x18\r \x01(\r\x12\x1a\n\x12timecode_userbits1\x18\x0e \x01(\r\x12\x1a\n\x12timecode_userbits2\x18\x0f \x01(\r\x12\x1a\n\x12timecode_userbits3\x18\x10 \x01(\r\x12\x11\n\ttimestamp\x18\x11 \x01(\x03\x12\x0c\n\x04type\x18\x12 \x01(\r\"\x9c\x03\n\x14V4l2DqbufFtraceEvent\x12\x11\n\tbytesused\x18\x01 \x01(\r\x12\r\n\x05\x66ield\x18\x02 \x01(\r\x12\r\n\x05\x66lags\x18\x03 \x01(\r\x12\r\n\x05index\x18\x04 \x01(\r\x12\r\n\x05minor\x18\x05 \x01(\x05\x12\x10\n\x08sequence\x18\x06 \x01(\r\x12\x16\n\x0etimecode_flags\x18\x07 \x01(\r\x12\x17\n\x0ftimecode_frames\x18\x08 \x01(\r\x12\x16\n\x0etimecode_hours\x18\t \x01(\r\x12\x18\n\x10timecode_minutes\x18\n \x01(\r\x12\x18\n\x10timecode_seconds\x18\x0b \x01(\r\x12\x15\n\rtimecode_type\x18\x0c \x01(\r\x12\x1a\n\x12timecode_userbits0\x18\r \x01(\r\x12\x1a\n\x12timecode_userbits1\x18\x0e \x01(\r\x12\x1a\n\x12timecode_userbits2\x18\x0f \x01(\r\x12\x1a\n\x12timecode_userbits3\x18\x10 \x01(\r\x12\x11\n\ttimestamp\x18\x11 \x01(\x03\x12\x0c\n\x04type\x18\x12 \x01(\r\"\xf2\x02\n\x1aVb2V4l2BufQueueFtraceEvent\x12\r\n\x05\x66ield\x18\x01 \x01(\r\x12\r\n\x05\x66lags\x18\x02 \x01(\r\x12\r\n\x05minor\x18\x03 \x01(\x05\x12\x10\n\x08sequence\x18\x04 \x01(\r\x12\x16\n\x0etimecode_flags\x18\x05 \x01(\r\x12\x17\n\x0ftimecode_frames\x18\x06 \x01(\r\x12\x16\n\x0etimecode_hours\x18\x07 \x01(\r\x12\x18\n\x10timecode_minutes\x18\x08 \x01(\r\x12\x18\n\x10timecode_seconds\x18\t \x01(\r\x12\x15\n\rtimecode_type\x18\n \x01(\r\x12\x1a\n\x12timecode_userbits0\x18\x0b \x01(\r\x12\x1a\n\x12timecode_userbits1\x18\x0c \x01(\r\x12\x1a\n\x12timecode_userbits2\x18\r \x01(\r\x12\x1a\n\x12timecode_userbits3\x18\x0e \x01(\r\x12\x11\n\ttimestamp\x18\x0f \x01(\x03\"\xf1\x02\n\x19Vb2V4l2BufDoneFtraceEvent\x12\r\n\x05\x66ield\x18\x01 \x01(\r\x12\r\n\x05\x66lags\x18\x02 \x01(\r\x12\r\n\x05minor\x18\x03 \x01(\x05\x12\x10\n\x08sequence\x18\x04 \x01(\r\x12\x16\n\x0etimecode_flags\x18\x05 \x01(\r\x12\x17\n\x0ftimecode_frames\x18\x06 \x01(\r\x12\x16\n\x0etimecode_hours\x18\x07 \x01(\r\x12\x18\n\x10timecode_minutes\x18\x08 \x01(\r\x12\x18\n\x10timecode_seconds\x18\t \x01(\r\x12\x15\n\rtimecode_type\x18\n \x01(\r\x12\x1a\n\x12timecode_userbits0\x18\x0b \x01(\r\x12\x1a\n\x12timecode_userbits1\x18\x0c \x01(\r\x12\x1a\n\x12timecode_userbits2\x18\r \x01(\r\x12\x1a\n\x12timecode_userbits3\x18\x0e \x01(\r\x12\x11\n\ttimestamp\x18\x0f \x01(\x03\"\xee\x02\n\x16Vb2V4l2QbufFtraceEvent\x12\r\n\x05\x66ield\x18\x01 \x01(\r\x12\r\n\x05\x66lags\x18\x02 \x01(\r\x12\r\n\x05minor\x18\x03 \x01(\x05\x12\x10\n\x08sequence\x18\x04 \x01(\r\x12\x16\n\x0etimecode_flags\x18\x05 \x01(\r\x12\x17\n\x0ftimecode_frames\x18\x06 \x01(\r\x12\x16\n\x0etimecode_hours\x18\x07 \x01(\r\x12\x18\n\x10timecode_minutes\x18\x08 \x01(\r\x12\x18\n\x10timecode_seconds\x18\t \x01(\r\x12\x15\n\rtimecode_type\x18\n \x01(\r\x12\x1a\n\x12timecode_userbits0\x18\x0b \x01(\r\x12\x1a\n\x12timecode_userbits1\x18\x0c \x01(\r\x12\x1a\n\x12timecode_userbits2\x18\r \x01(\r\x12\x1a\n\x12timecode_userbits3\x18\x0e \x01(\r\x12\x11\n\ttimestamp\x18\x0f \x01(\x03\"\xef\x02\n\x17Vb2V4l2DqbufFtraceEvent\x12\r\n\x05\x66ield\x18\x01 \x01(\r\x12\r\n\x05\x66lags\x18\x02 \x01(\r\x12\r\n\x05minor\x18\x03 \x01(\x05\x12\x10\n\x08sequence\x18\x04 \x01(\r\x12\x16\n\x0etimecode_flags\x18\x05 \x01(\r\x12\x17\n\x0ftimecode_frames\x18\x06 \x01(\r\x12\x16\n\x0etimecode_hours\x18\x07 \x01(\r\x12\x18\n\x10timecode_minutes\x18\x08 \x01(\r\x12\x18\n\x10timecode_seconds\x18\t \x01(\r\x12\x15\n\rtimecode_type\x18\n \x01(\r\x12\x1a\n\x12timecode_userbits0\x18\x0b \x01(\r\x12\x1a\n\x12timecode_userbits1\x18\x0c \x01(\r\x12\x1a\n\x12timecode_userbits2\x18\r \x01(\r\x12\x1a\n\x12timecode_userbits3\x18\x0e \x01(\r\x12\x11\n\ttimestamp\x18\x0f \x01(\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.ftrace.v4l2_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_V4L2QBUFFTRACEEVENT']._serialized_start=61
  _globals['_V4L2QBUFFTRACEEVENT']._serialized_end=472
  _globals['_V4L2DQBUFFTRACEEVENT']._serialized_start=475
  _globals['_V4L2DQBUFFTRACEEVENT']._serialized_end=887
  _globals['_VB2V4L2BUFQUEUEFTRACEEVENT']._serialized_start=890
  _globals['_VB2V4L2BUFQUEUEFTRACEEVENT']._serialized_end=1260
  _globals['_VB2V4L2BUFDONEFTRACEEVENT']._serialized_start=1263
  _globals['_VB2V4L2BUFDONEFTRACEEVENT']._serialized_end=1632
  _globals['_VB2V4L2QBUFFTRACEEVENT']._serialized_start=1635
  _globals['_VB2V4L2QBUFFTRACEEVENT']._serialized_end=2001
  _globals['_VB2V4L2DQBUFFTRACEEVENT']._serialized_start=2004
  _globals['_VB2V4L2DQBUFFTRACEEVENT']._serialized_end=2371
# @@protoc_insertion_point(module_scope)



import datetime
import pandas
import re

def format_datetime(value):
    nonetype = type(None)
    value_type = type(value)
    if value_type == datetime.datetime:
        if value.tzinfo is None:
            raise RuntimeError("datetime needs a valid time zone")
        return value.isoformat()
    elif value_type == pandas.Timestamp:
        return value.isoformat()
    elif value_type == str:
        return format_datetime(datetime.datetime.fromisoformat(value))
    elif value_type == type(None):
        return None
    raise RuntimeError("value of unknown type in format_datetime")

def parse_time_delta(user_string):
    parser = re.compile("(\\d+)([mhd])")
    m = parser.match(user_string)
    nbr = int(m.group(1))
    unit = m.group(2)
    if unit == "m":
        return datetime.timedelta(minutes=nbr)
    elif unit == "h":
        return datetime.timedelta(hours=nbr)
    elif unit == "d":
        return datetime.timedelta(days=nbr)
    else:
        raise RuntimeError("invalid time delta: " + user_string)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/track_event/counter_descriptor.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/track_event/counter_descriptor.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:protos/perfetto/trace/track_event/counter_descriptor.proto\x12\x0fperfetto.protos\"\xad\x03\n\x11\x43ounterDescriptor\x12\x43\n\x04type\x18\x01 \x01(\x0e\x32\x35.perfetto.protos.CounterDescriptor.BuiltinCounterType\x12\x12\n\ncategories\x18\x02 \x03(\t\x12\x35\n\x04unit\x18\x03 \x01(\x0e\x32\'.perfetto.protos.CounterDescriptor.Unit\x12\x11\n\tunit_name\x18\x06 \x01(\t\x12\x17\n\x0funit_multiplier\x18\x04 \x01(\x03\x12\x16\n\x0eis_incremental\x18\x05 \x01(\x08\"o\n\x12\x42uiltinCounterType\x12\x17\n\x13\x43OUNTER_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x43OUNTER_THREAD_TIME_NS\x10\x01\x12$\n COUNTER_THREAD_INSTRUCTION_COUNT\x10\x02\"S\n\x04Unit\x12\x14\n\x10UNIT_UNSPECIFIED\x10\x00\x12\x10\n\x0cUNIT_TIME_NS\x10\x01\x12\x0e\n\nUNIT_COUNT\x10\x02\x12\x13\n\x0fUNIT_SIZE_BYTES\x10\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.track_event.counter_descriptor_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_COUNTERDESCRIPTOR']._serialized_start=80
  _globals['_COUNTERDESCRIPTOR']._serialized_end=509
  _globals['_COUNTERDESCRIPTOR_BUILTINCOUNTERTYPE']._serialized_start=313
  _globals['_COUNTERDESCRIPTOR_BUILTINCOUNTERTYPE']._serialized_end=424
  _globals['_COUNTERDESCRIPTOR_UNIT']._serialized_start=426
  _globals['_COUNTERDESCRIPTOR_UNIT']._serialized_end=509
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/trace_packet.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/trace_packet.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protos.perfetto.common import trace_stats_pb2 as protos_dot_perfetto_dot_common_dot_trace__stats__pb2
from protos.perfetto.config import trace_config_pb2 as protos_dot_perfetto_dot_config_dot_trace__config__pb2
from protos.perfetto.trace import extension_descriptor_pb2 as protos_dot_perfetto_dot_trace_dot_extension__descriptor__pb2
from protos.perfetto.trace.android import android_game_intervention_list_pb2 as protos_dot_perfetto_dot_trace_dot_android_dot_android__game__intervention__list__pb2
from protos.perfetto.trace.android import android_log_pb2 as protos_dot_perfetto_dot_trace_dot_android_dot_android__log__pb2
from protos.perfetto.trace.android import android_system_property_pb2 as protos_dot_perfetto_dot_trace_dot_android_dot_android__system__property__pb2
from protos.perfetto.trace.android import camera_event_pb2 as protos_dot_perfetto_dot_trace_dot_android_dot_camera__event__pb2
from protos.perfetto.trace.android import frame_timeline_event_pb2 as protos_dot_perfetto_dot_trace_dot_android_dot_frame__timeline__event__pb2
from protos.perfetto.trace.android import gpu_mem_event_pb2 as protos_dot_perfetto_dot_trace_dot_android_dot_gpu__mem__event__pb2
from protos.perfetto.trace.android import graphics_frame_event_pb2 as protos_dot_perfetto_dot_trace_dot_android_dot_graphics__frame__event__pb2
from protos.perfetto.trace.android import initial_display_state_pb2 as protos_dot_perfetto_dot_trace_dot_android_dot_initial__display__state__pb2
from protos.perfetto.trace.android import network_trace_pb2 as protos_dot_perfetto_dot_trace_dot_android_dot_network__trace__pb2
from protos.perfetto.trace.android import packages_list_pb2 as protos_dot_perfetto_dot_trace_dot_android_dot_packages__list__pb2
from protos.perfetto.trace.android import pixel_modem_events_pb2 as protos_dot_perfetto_dot_trace_dot_android_dot_pixel__modem__events__pb2
from protos.perfetto.trace.android import protolog_pb2 as protos_dot_perfetto_dot_trace_dot_android_dot_protolog__pb2
from protos.perfetto.trace.android import shell_transition_pb2 as protos_dot_perfetto_dot_trace_dot_android_dot_shell__transition__pb2
from protos.perfetto.trace.android import surfaceflinger_layers_pb2 as protos_dot_perfetto_dot_trace_dot_android_dot_surfaceflinger__layers__pb2
from protos.perfetto.trace.android import surfaceflinger_transactions_pb2 as protos_dot_perfetto_dot_trace_dot_android_dot_surfaceflinger__transactions__pb2
from protos.perfetto.trace.android import winscope_extensions_pb2 as protos_dot_perfetto_dot_trace_dot_android_dot_winscope__extensions__pb2
from protos.perfetto.trace.chrome import chrome_benchmark_metadata_pb2 as protos_dot_perfetto_dot_trace_dot_chrome_dot_chrome__benchmark__metadata__pb2
from protos.perfetto.trace.chrome import chrome_metadata_pb2 as protos_dot_perfetto_dot_trace_dot_chrome_dot_chrome__metadata__pb2
from protos.perfetto.trace.chrome import chrome_trace_event_pb2 as protos_dot_perfetto_dot_trace_dot_chrome_dot_chrome__trace__event__pb2
from protos.perfetto.trace.chrome import chrome_trigger_pb2 as protos_dot_perfetto_dot_trace_dot_chrome_dot_chrome__trigger__pb2
from protos.perfetto.trace.chrome import v8_pb2 as protos_dot_perfetto_dot_trace_dot_chrome_dot_v8__pb2
from protos.perfetto.trace import clock_snapshot_pb2 as protos_dot_perfetto_dot_trace_dot_clock__snapshot__pb2
from protos.perfetto.trace.etw import etw_event_bundle_pb2 as protos_dot_perfetto_dot_trace_dot_etw_dot_etw__event__bundle__pb2
from protos.perfetto.trace.filesystem import inode_file_map_pb2 as protos_dot_perfetto_dot_trace_dot_filesystem_dot_inode__file__map__pb2
from protos.perfetto.trace.ftrace import ftrace_event_bundle_pb2 as protos_dot_perfetto_dot_trace_dot_ftrace_dot_ftrace__event__bundle__pb2
from protos.perfetto.trace.ftrace import ftrace_stats_pb2 as protos_dot_perfetto_dot_trace_dot_ftrace_dot_ftrace__stats__pb2
from protos.perfetto.trace.gpu import gpu_counter_event_pb2 as protos_dot_perfetto_dot_trace_dot_gpu_dot_gpu__counter__event__pb2
from protos.perfetto.trace.gpu import gpu_log_pb2 as protos_dot_perfetto_dot_trace_dot_gpu_dot_gpu__log__pb2
from protos.perfetto.trace.gpu import gpu_render_stage_event_pb2 as protos_dot_perfetto_dot_trace_dot_gpu_dot_gpu__render__stage__event__pb2
from protos.perfetto.trace.gpu import vulkan_memory_event_pb2 as protos_dot_perfetto_dot_trace_dot_gpu_dot_vulkan__memory__event__pb2
from protos.perfetto.trace.gpu import vulkan_api_event_pb2 as protos_dot_perfetto_dot_trace_dot_gpu_dot_vulkan__api__event__pb2
from protos.perfetto.trace.interned_data import interned_data_pb2 as protos_dot_perfetto_dot_trace_dot_interned__data_dot_interned__data__pb2
from protos.perfetto.trace import memory_graph_pb2 as protos_dot_perfetto_dot_trace_dot_memory__graph__pb2
from protos.perfetto.trace.perfetto import perfetto_metatrace_pb2 as protos_dot_perfetto_dot_trace_dot_perfetto_dot_perfetto__metatrace__pb2
from protos.perfetto.trace.perfetto import tracing_service_event_pb2 as protos_dot_perfetto_dot_trace_dot_perfetto_dot_tracing__service__event__pb2
from protos.perfetto.trace.power import android_energy_estimation_breakdown_pb2 as protos_dot_perfetto_dot_trace_dot_power_dot_android__energy__estimation__breakdown__pb2
from protos.perfetto.trace.power import android_entity_state_residency_pb2 as protos_dot_perfetto_dot_trace_dot_power_dot_android__entity__state__residency__pb2
from protos.perfetto.trace.power import battery_counters_pb2 as protos_dot_perfetto_dot_trace_dot_power_dot_battery__counters__pb2
from protos.perfetto.trace.power import power_rails_pb2 as protos_dot_perfetto_dot_trace_dot_power_dot_power__rails__pb2
from protos.perfetto.trace.statsd import statsd_atom_pb2 as protos_dot_perfetto_dot_trace_dot_statsd_dot_statsd__atom__pb2
from protos.perfetto.trace.profiling import deobfuscation_pb2 as protos_dot_perfetto_dot_trace_dot_profiling_dot_deobfuscation__pb2
from protos.perfetto.trace.profiling import heap_graph_pb2 as protos_dot_perfetto_dot_trace_dot_profiling_dot_heap__graph__pb2
try:
  protos_dot_perfetto_dot_trace_dot_profiling_dot_deobfuscation__pb2 = protos_dot_perfetto_dot_trace_dot_profiling_dot_heap__graph__pb2.protos_dot_perfetto_dot_trace_dot_profiling_dot_deobfuscation__pb2
except AttributeError:
  protos_dot_perfetto_dot_trace_dot_profiling_dot_deobfuscation__pb2 = protos_dot_perfetto_dot_trace_dot_profiling_dot_heap__graph__pb2.protos.perfetto.trace.profiling.deobfuscation_pb2
from protos.perfetto.trace.profiling import profile_common_pb2 as protos_dot_perfetto_dot_trace_dot_profiling_dot_profile__common__pb2
from protos.perfetto.trace.profiling import profile_packet_pb2 as protos_dot_perfetto_dot_trace_dot_profiling_dot_profile__packet__pb2
from protos.perfetto.trace.profiling import smaps_pb2 as protos_dot_perfetto_dot_trace_dot_profiling_dot_smaps__pb2
from protos.perfetto.trace.ps import process_stats_pb2 as protos_dot_perfetto_dot_trace_dot_ps_dot_process__stats__pb2
from protos.perfetto.trace.ps import process_tree_pb2 as protos_dot_perfetto_dot_trace_dot_ps_dot_process__tree__pb2
from protos.perfetto.trace import remote_clock_sync_pb2 as protos_dot_perfetto_dot_trace_dot_remote__clock__sync__pb2
from protos.perfetto.trace.sys_stats import sys_stats_pb2 as protos_dot_perfetto_dot_trace_dot_sys__stats_dot_sys__stats__pb2
from protos.perfetto.trace import system_info_pb2 as protos_dot_perfetto_dot_trace_dot_system__info__pb2
from protos.perfetto.trace.system_info import cpu_info_pb2 as protos_dot_perfetto_dot_trace_dot_system__info_dot_cpu__info__pb2
from protos.perfetto.trace import trace_packet_defaults_pb2 as protos_dot_perfetto_dot_trace_dot_trace__packet__defaults__pb2
from protos.perfetto.trace.track_event import process_descriptor_pb2 as protos_dot_perfetto_dot_trace_dot_track__event_dot_process__descriptor__pb2
from protos.perfetto.trace.track_event import range_of_interest_pb2 as protos_dot_perfetto_dot_trace_dot_track__event_dot_range__of__interest__pb2
from protos.perfetto.trace.track_event import thread_descriptor_pb2 as protos_dot_perfetto_dot_trace_dot_track__event_dot_thread__descriptor__pb2
from protos.perfetto.trace.track_event import track_descriptor_pb2 as protos_dot_perfetto_dot_trace_dot_track__event_dot_track__descriptor__pb2
from protos.perfetto.trace.track_event import track_event_pb2 as protos_dot_perfetto_dot_trace_dot_track__event_dot_track__event__pb2
from protos.perfetto.trace.translation import translation_table_pb2 as protos_dot_perfetto_dot_trace_dot_translation_dot_translation__table__pb2
from protos.perfetto.trace import trace_uuid_pb2 as protos_dot_perfetto_dot_trace_dot_trace__uuid__pb2
from protos.perfetto.trace import trigger_pb2 as protos_dot_perfetto_dot_trace_dot_trigger__pb2
from protos.perfetto.trace import test_event_pb2 as protos_dot_perfetto_dot_trace_dot_test__event__pb2
from protos.perfetto.trace import ui_state_pb2 as protos_dot_perfetto_dot_trace_dot_ui__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(protos/perfetto/trace/trace_packet.proto\x12\x0fperfetto.protos\x1a(protos/perfetto/common/trace_stats.proto\x1a)protos/perfetto/config/trace_config.proto\x1a\x30protos/perfetto/trace/extension_descriptor.proto\x1a\x42protos/perfetto/trace/android/android_game_intervention_list.proto\x1a/protos/perfetto/trace/android/android_log.proto\x1a;protos/perfetto/trace/android/android_system_property.proto\x1a\x30protos/perfetto/trace/android/camera_event.proto\x1a\x38protos/perfetto/trace/android/frame_timeline_event.proto\x1a\x31protos/perfetto/trace/android/gpu_mem_event.proto\x1a\x38protos/perfetto/trace/android/graphics_frame_event.proto\x1a\x39protos/perfetto/trace/android/initial_display_state.proto\x1a\x31protos/perfetto/trace/android/network_trace.proto\x1a\x31protos/perfetto/trace/android/packages_list.proto\x1a\x36protos/perfetto/trace/android/pixel_modem_events.proto\x1a,protos/perfetto/trace/android/protolog.proto\x1a\x34protos/perfetto/trace/android/shell_transition.proto\x1a\x39protos/perfetto/trace/android/surfaceflinger_layers.proto\x1a?protos/perfetto/trace/android/surfaceflinger_transactions.proto\x1a\x37protos/perfetto/trace/android/winscope_extensions.proto\x1a<protos/perfetto/trace/chrome/chrome_benchmark_metadata.proto\x1a\x32protos/perfetto/trace/chrome/chrome_metadata.proto\x1a\x35protos/perfetto/trace/chrome/chrome_trace_event.proto\x1a\x31protos/perfetto/trace/chrome/chrome_trigger.proto\x1a%protos/perfetto/trace/chrome/v8.proto\x1a*protos/perfetto/trace/clock_snapshot.proto\x1a\x30protos/perfetto/trace/etw/etw_event_bundle.proto\x1a\x35protos/perfetto/trace/filesystem/inode_file_map.proto\x1a\x36protos/perfetto/trace/ftrace/ftrace_event_bundle.proto\x1a/protos/perfetto/trace/ftrace/ftrace_stats.proto\x1a\x31protos/perfetto/trace/gpu/gpu_counter_event.proto\x1a\'protos/perfetto/trace/gpu/gpu_log.proto\x1a\x36protos/perfetto/trace/gpu/gpu_render_stage_event.proto\x1a\x33protos/perfetto/trace/gpu/vulkan_memory_event.proto\x1a\x30protos/perfetto/trace/gpu/vulkan_api_event.proto\x1a\x37protos/perfetto/trace/interned_data/interned_data.proto\x1a(protos/perfetto/trace/memory_graph.proto\x1a\x37protos/perfetto/trace/perfetto/perfetto_metatrace.proto\x1a:protos/perfetto/trace/perfetto/tracing_service_event.proto\x1a\x45protos/perfetto/trace/power/android_energy_estimation_breakdown.proto\x1a@protos/perfetto/trace/power/android_entity_state_residency.proto\x1a\x32protos/perfetto/trace/power/battery_counters.proto\x1a-protos/perfetto/trace/power/power_rails.proto\x1a.protos/perfetto/trace/statsd/statsd_atom.proto\x1a\x33protos/perfetto/trace/profiling/deobfuscation.proto\x1a\x30protos/perfetto/trace/profiling/heap_graph.proto\x1a\x34protos/perfetto/trace/profiling/profile_common.proto\x1a\x34protos/perfetto/trace/profiling/profile_packet.proto\x1a+protos/perfetto/trace/profiling/smaps.proto\x1a,protos/perfetto/trace/ps/process_stats.proto\x1a+protos/perfetto/trace/ps/process_tree.proto\x1a-protos/perfetto/trace/remote_clock_sync.proto\x1a/protos/perfetto/trace/sys_stats/sys_stats.proto\x1a\'protos/perfetto/trace/system_info.proto\x1a\x30protos/perfetto/trace/system_info/cpu_info.proto\x1a\x31protos/perfetto/trace/trace_packet_defaults.proto\x1a:protos/perfetto/trace/track_event/process_descriptor.proto\x1a\x39protos/perfetto/trace/track_event/range_of_interest.proto\x1a\x39protos/perfetto/trace/track_event/thread_descriptor.proto\x1a\x38protos/perfetto/trace/track_event/track_descriptor.proto\x1a\x33protos/perfetto/trace/track_event/track_event.proto\x1a\x39protos/perfetto/trace/translation/translation_table.proto\x1a&protos/perfetto/trace/trace_uuid.proto\x1a#protos/perfetto/trace/trigger.proto\x1a&protos/perfetto/trace/test_event.proto\x1a$protos/perfetto/trace/ui_state.proto\"\x90+\n\x0bTracePacket\x12\x11\n\ttimestamp\x18\x08 \x01(\x04\x12\x1a\n\x12timestamp_clock_id\x18: \x01(\r\x12\x34\n\x0cprocess_tree\x18\x02 \x01(\x0b\x32\x1c.perfetto.protos.ProcessTreeH\x00\x12\x36\n\rprocess_stats\x18\t \x01(\x0b\x32\x1d.perfetto.protos.ProcessStatsH\x00\x12\x37\n\x0einode_file_map\x18\x04 \x01(\x0b\x32\x1d.perfetto.protos.InodeFileMapH\x00\x12;\n\rchrome_events\x18\x05 \x01(\x0b\x32\".perfetto.protos.ChromeEventBundleH\x00\x12\x38\n\x0e\x63lock_snapshot\x18\x06 \x01(\x0b\x32\x1e.perfetto.protos.ClockSnapshotH\x00\x12.\n\tsys_stats\x18\x07 \x01(\x0b\x32\x19.perfetto.protos.SysStatsH\x00\x12\x32\n\x0btrack_event\x18\x0b \x01(\x0b\x32\x1b.perfetto.protos.TrackEventH\x00\x12\x30\n\ntrace_uuid\x18Y \x01(\x0b\x32\x1a.perfetto.protos.TraceUuidH\x00\x12\x34\n\x0ctrace_config\x18! \x01(\x0b\x32\x1c.perfetto.protos.TraceConfigH\x00\x12\x34\n\x0c\x66trace_stats\x18\" \x01(\x0b\x32\x1c.perfetto.protos.FtraceStatsH\x00\x12\x32\n\x0btrace_stats\x18# \x01(\x0b\x32\x1b.perfetto.protos.TraceStatsH\x00\x12\x38\n\x0eprofile_packet\x18% \x01(\x0b\x32\x1e.perfetto.protos.ProfilePacketH\x00\x12\x44\n\x14streaming_allocation\x18J \x01(\x0b\x32$.perfetto.protos.StreamingAllocationH\x00\x12\x38\n\x0estreaming_free\x18K \x01(\x0b\x32\x1e.perfetto.protos.StreamingFreeH\x00\x12\x33\n\x07\x62\x61ttery\x18& \x01(\x0b\x32 .perfetto.protos.BatteryCountersH\x00\x12\x32\n\x0bpower_rails\x18( \x01(\x0b\x32\x1b.perfetto.protos.PowerRailsH\x00\x12\x38\n\x0b\x61ndroid_log\x18\' \x01(\x0b\x32!.perfetto.protos.AndroidLogPacketH\x00\x12\x32\n\x0bsystem_info\x18- \x01(\x0b\x32\x1b.perfetto.protos.SystemInfoH\x00\x12+\n\x07trigger\x18. \x01(\x0b\x32\x18.perfetto.protos.TriggerH\x00\x12\x38\n\x0e\x63hrome_trigger\x18m \x01(\x0b\x32\x1e.perfetto.protos.ChromeTriggerH\x00\x12\x36\n\rpackages_list\x18/ \x01(\x0b\x32\x1d.perfetto.protos.PackagesListH\x00\x12M\n\x19\x63hrome_benchmark_metadata\x18\x30 \x01(\x0b\x32(.perfetto.protos.ChromeBenchmarkMetadataH\x00\x12@\n\x12perfetto_metatrace\x18\x31 \x01(\x0b\x32\".perfetto.protos.PerfettoMetatraceH\x00\x12@\n\x0f\x63hrome_metadata\x18\x33 \x01(\x0b\x32%.perfetto.protos.ChromeMetadataPacketH\x00\x12=\n\x11gpu_counter_event\x18\x34 \x01(\x0b\x32 .perfetto.protos.GpuCounterEventH\x00\x12\x46\n\x16gpu_render_stage_event\x18\x35 \x01(\x0b\x32$.perfetto.protos.GpuRenderStageEventH\x00\x12K\n\x18streaming_profile_packet\x18\x36 \x01(\x0b\x32\'.perfetto.protos.StreamingProfilePacketH\x00\x12\x30\n\nheap_graph\x18\x38 \x01(\x0b\x32\x1a.perfetto.protos.HeapGraphH\x00\x12\x43\n\x14graphics_frame_event\x18\x39 \x01(\x0b\x32#.perfetto.protos.GraphicsFrameEventH\x00\x12\x41\n\x13vulkan_memory_event\x18> \x01(\x0b\x32\".perfetto.protos.VulkanMemoryEventH\x00\x12*\n\x07gpu_log\x18? \x01(\x0b\x32\x17.perfetto.protos.GpuLogH\x00\x12;\n\x10vulkan_api_event\x18\x41 \x01(\x0b\x32\x1f.perfetto.protos.VulkanApiEventH\x00\x12\x32\n\x0bperf_sample\x18\x42 \x01(\x0b\x32\x1b.perfetto.protos.PerfSampleH\x00\x12,\n\x08\x63pu_info\x18\x43 \x01(\x0b\x32\x18.perfetto.protos.CpuInfoH\x00\x12\x34\n\x0csmaps_packet\x18\x44 \x01(\x0b\x32\x1c.perfetto.protos.SmapsPacketH\x00\x12=\n\rservice_event\x18\x45 \x01(\x0b\x32$.perfetto.protos.TracingServiceEventH\x00\x12\x45\n\x15initial_display_state\x18\x46 \x01(\x0b\x32$.perfetto.protos.InitialDisplayStateH\x00\x12@\n\x13gpu_mem_total_event\x18G \x01(\x0b\x32!.perfetto.protos.GpuMemTotalEventH\x00\x12I\n\x17memory_tracker_snapshot\x18I \x01(\x0b\x32&.perfetto.protos.MemoryTrackerSnapshotH\x00\x12\x43\n\x14\x66rame_timeline_event\x18L \x01(\x0b\x32#.perfetto.protos.FrameTimelineEventH\x00\x12`\n#android_energy_estimation_breakdown\x18M \x01(\x0b\x32\x31.perfetto.protos.AndroidEnergyEstimationBreakdownH\x00\x12,\n\x08ui_state\x18N \x01(\x0b\x32\x18.perfetto.protos.UiStateH\x00\x12N\n\x1a\x61ndroid_camera_frame_event\x18P \x01(\x0b\x32(.perfetto.protos.AndroidCameraFrameEventH\x00\x12R\n\x1c\x61ndroid_camera_session_stats\x18Q \x01(\x0b\x32*.perfetto.protos.AndroidCameraSessionStatsH\x00\x12>\n\x11translation_table\x18R \x01(\x0b\x32!.perfetto.protos.TranslationTableH\x00\x12V\n\x1e\x61ndroid_game_intervention_list\x18S \x01(\x0b\x32,.perfetto.protos.AndroidGameInterventionListH\x00\x12\x32\n\x0bstatsd_atom\x18T \x01(\x0b\x32\x1b.perfetto.protos.StatsdAtomH\x00\x12I\n\x17\x61ndroid_system_property\x18V \x01(\x0b\x32&.perfetto.protos.AndroidSystemPropertyH\x00\x12G\n\x16\x65ntity_state_residency\x18[ \x01(\x0b\x32%.perfetto.protos.EntityStateResidencyH\x00\x12G\n\x16profiled_frame_symbols\x18\x37 \x01(\x0b\x32%.perfetto.protos.ProfiledFrameSymbolsH\x00\x12\x38\n\x0emodule_symbols\x18= \x01(\x0b\x32\x1e.perfetto.protos.ModuleSymbolsH\x00\x12\x46\n\x15\x64\x65obfuscation_mapping\x18@ \x01(\x0b\x32%.perfetto.protos.DeobfuscationMappingH\x00\x12<\n\x10track_descriptor\x18< \x01(\x0b\x32 .perfetto.protos.TrackDescriptorH\x00\x12@\n\x12process_descriptor\x18+ \x01(\x0b\x32\".perfetto.protos.ProcessDescriptorH\x00\x12>\n\x11thread_descriptor\x18, \x01(\x0b\x32!.perfetto.protos.ThreadDescriptorH\x00\x12;\n\rftrace_events\x18\x01 \x01(\x0b\x32\".perfetto.protos.FtraceEventBundleH\x00\x12 \n\x16synchronization_marker\x18$ \x01(\x0cH\x00\x12\x1c\n\x12\x63ompressed_packets\x18\x32 \x01(\x0cH\x00\x12\x44\n\x14\x65xtension_descriptor\x18H \x01(\x0b\x32$.perfetto.protos.ExtensionDescriptorH\x00\x12=\n\x0enetwork_packet\x18X \x01(\x0b\x32#.perfetto.protos.NetworkPacketEventH\x00\x12\x45\n\x15network_packet_bundle\x18\\ \x01(\x0b\x32$.perfetto.protos.NetworkPacketBundleH\x00\x12S\n\x1dtrack_event_range_of_interest\x18Z \x01(\x0b\x32*.perfetto.protos.TrackEventRangeOfInterestH\x00\x12N\n\x1esurfaceflinger_layers_snapshot\x18] \x01(\x0b\x32$.perfetto.protos.LayersSnapshotProtoH\x00\x12M\n\x1bsurfaceflinger_transactions\x18^ \x01(\x0b\x32&.perfetto.protos.TransactionTraceEntryH\x00\x12<\n\x10shell_transition\x18` \x01(\x0b\x32 .perfetto.protos.ShellTransitionH\x00\x12G\n\x16shell_handler_mappings\x18\x61 \x01(\x0b\x32%.perfetto.protos.ShellHandlerMappingsH\x00\x12<\n\x10protolog_message\x18h \x01(\x0b\x32 .perfetto.protos.ProtoLogMessageH\x00\x12G\n\x16protolog_viewer_config\x18i \x01(\x0b\x32%.perfetto.protos.ProtoLogViewerConfigH\x00\x12\x42\n\x13winscope_extensions\x18p \x01(\x0b\x32#.perfetto.protos.WinscopeExtensionsH\x00\x12:\n\netw_events\x18_ \x01(\x0b\x32$.perfetto.protos.EtwTraceEventBundleH\x00\x12/\n\nv8_js_code\x18\x63 \x01(\x0b\x32\x19.perfetto.protos.V8JsCodeH\x00\x12;\n\x10v8_internal_code\x18\x64 \x01(\x0b\x32\x1f.perfetto.protos.V8InternalCodeH\x00\x12\x33\n\x0cv8_wasm_code\x18\x65 \x01(\x0b\x32\x1b.perfetto.protos.V8WasmCodeH\x00\x12\x38\n\x0fv8_reg_exp_code\x18\x66 \x01(\x0b\x32\x1d.perfetto.protos.V8RegExpCodeH\x00\x12\x33\n\x0cv8_code_move\x18g \x01(\x0b\x32\x1b.perfetto.protos.V8CodeMoveH\x00\x12=\n\x11remote_clock_sync\x18k \x01(\x0b\x32 .perfetto.protos.RemoteClockSyncH\x00\x12?\n\x12pixel_modem_events\x18n \x01(\x0b\x32!.perfetto.protos.PixelModemEventsH\x00\x12N\n\x1apixel_modem_token_database\x18o \x01(\x0b\x32(.perfetto.protos.PixelModemTokenDatabaseH\x00\x12\x32\n\x0b\x66or_testing\x18\x84\x07 \x01(\x0b\x32\x1a.perfetto.protos.TestEventH\x00\x12\x15\n\x0btrusted_uid\x18\x03 \x01(\x05H\x01\x12$\n\x1atrusted_packet_sequence_id\x18\n \x01(\rH\x02\x12\x13\n\x0btrusted_pid\x18O \x01(\x05\x12\x34\n\rinterned_data\x18\x0c \x01(\x0b\x32\x1d.perfetto.protos.InternedData\x12\x16\n\x0esequence_flags\x18\r \x01(\r\x12!\n\x19incremental_state_cleared\x18) \x01(\x08\x12\x43\n\x15trace_packet_defaults\x18; \x01(\x0b\x32$.perfetto.protos.TracePacketDefaults\x12\x1f\n\x17previous_packet_dropped\x18* \x01(\x08\x12 \n\x18\x66irst_packet_on_sequence\x18W \x01(\x08\x12\x12\n\nmachine_id\x18\x62 \x01(\r\"h\n\rSequenceFlags\x12\x13\n\x0fSEQ_UNSPECIFIED\x10\x00\x12!\n\x1dSEQ_INCREMENTAL_STATE_CLEARED\x10\x01\x12\x1f\n\x1bSEQ_NEEDS_INCREMENTAL_STATE\x10\x02\x42\x06\n\x04\x64\x61taB\x16\n\x14optional_trusted_uidB%\n#optional_trusted_packet_sequence_idJ\x04\x08j\x10k')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.trace_packet_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TRACEPACKET']._serialized_start=3442
  _globals['_TRACEPACKET']._serialized_end=8962
  _globals['_TRACEPACKET_SEQUENCEFLAGS']._serialized_start=8781
  _globals['_TRACEPACKET_SEQUENCEFLAGS']._serialized_end=8885
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/config/sys_stats/sys_stats_config.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/config/sys_stats/sys_stats_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protos.perfetto.common import sys_stats_counters_pb2 as protos_dot_perfetto_dot_common_dot_sys__stats__counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7protos/perfetto/config/sys_stats/sys_stats_config.proto\x12\x0fperfetto.protos\x1a/protos/perfetto/common/sys_stats_counters.proto\"\x9b\x04\n\x0eSysStatsConfig\x12\x19\n\x11meminfo_period_ms\x18\x01 \x01(\r\x12:\n\x10meminfo_counters\x18\x02 \x03(\x0e\x32 .perfetto.protos.MeminfoCounters\x12\x18\n\x10vmstat_period_ms\x18\x03 \x01(\r\x12\x38\n\x0fvmstat_counters\x18\x04 \x03(\x0e\x32\x1f.perfetto.protos.VmstatCounters\x12\x16\n\x0estat_period_ms\x18\x05 \x01(\r\x12\x43\n\rstat_counters\x18\x06 \x03(\x0e\x32,.perfetto.protos.SysStatsConfig.StatCounters\x12\x19\n\x11\x64\x65vfreq_period_ms\x18\x07 \x01(\r\x12\x19\n\x11\x63pufreq_period_ms\x18\x08 \x01(\r\x12\x1b\n\x13\x62uddyinfo_period_ms\x18\t \x01(\r\x12\x1a\n\x12\x64iskstat_period_ms\x18\n \x01(\r\x12\x15\n\rpsi_period_ms\x18\x0b \x01(\r\"{\n\x0cStatCounters\x12\x14\n\x10STAT_UNSPECIFIED\x10\x00\x12\x12\n\x0eSTAT_CPU_TIMES\x10\x01\x12\x13\n\x0fSTAT_IRQ_COUNTS\x10\x02\x12\x17\n\x13STAT_SOFTIRQ_COUNTS\x10\x03\x12\x13\n\x0fSTAT_FORK_COUNT\x10\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.config.sys_stats.sys_stats_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SYSSTATSCONFIG']._serialized_start=126
  _globals['_SYSSTATSCONFIG']._serialized_end=665
  _globals['_SYSSTATSCONFIG_STATCOUNTERS']._serialized_start=542
  _globals['_SYSSTATSCONFIG_STATCOUNTERS']._serialized_end=665
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/ui_state.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/ui_state.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$protos/perfetto/trace/ui_state.proto\x12\x0fperfetto.protos\"\xc5\x01\n\x07UiState\x12\x19\n\x11timeline_start_ts\x18\x01 \x01(\x03\x12\x17\n\x0ftimeline_end_ts\x18\x02 \x01(\x03\x12\x44\n\x11highlight_process\x18\x03 \x01(\x0b\x32).perfetto.protos.UiState.HighlightProcess\x1a@\n\x10HighlightProcess\x12\r\n\x03pid\x18\x01 \x01(\rH\x00\x12\x11\n\x07\x63mdline\x18\x02 \x01(\tH\x00\x42\n\n\x08selector')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.ui_state_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_UISTATE']._serialized_start=58
  _globals['_UISTATE']._serialized_end=255
  _globals['_UISTATE_HIGHLIGHTPROCESS']._serialized_start=191
  _globals['_UISTATE_HIGHLIGHTPROCESS']._serialized_end=255
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/remote_clock_sync.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/remote_clock_sync.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protos.perfetto.trace import clock_snapshot_pb2 as protos_dot_perfetto_dot_trace_dot_clock__snapshot__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-protos/perfetto/trace/remote_clock_sync.proto\x12\x0fperfetto.protos\x1a*protos/perfetto/trace/clock_snapshot.proto\"\xd3\x01\n\x0fRemoteClockSync\x12\x44\n\rsynced_clocks\x18\x01 \x03(\x0b\x32-.perfetto.protos.RemoteClockSync.SyncedClocks\x1az\n\x0cSyncedClocks\x12\x35\n\rclient_clocks\x18\x02 \x01(\x0b\x32\x1e.perfetto.protos.ClockSnapshot\x12\x33\n\x0bhost_clocks\x18\x03 \x01(\x0b\x32\x1e.perfetto.protos.ClockSnapshot')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.remote_clock_sync_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REMOTECLOCKSYNC']._serialized_start=111
  _globals['_REMOTECLOCKSYNC']._serialized_end=322
  _globals['_REMOTECLOCKSYNC_SYNCEDCLOCKS']._serialized_start=200
  _globals['_REMOTECLOCKSYNC_SYNCEDCLOCKS']._serialized_end=322
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/android/surfaceflinger_layers.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/android/surfaceflinger_layers.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protos.perfetto.trace.android import surfaceflinger_common_pb2 as protos_dot_perfetto_dot_trace_dot_android_dot_surfaceflinger__common__pb2
from protos.perfetto.trace.android.graphics import rect_pb2 as protos_dot_perfetto_dot_trace_dot_android_dot_graphics_dot_rect__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9protos/perfetto/trace/android/surfaceflinger_layers.proto\x12\x0fperfetto.protos\x1a\x39protos/perfetto/trace/android/surfaceflinger_common.proto\x1a\x31protos/perfetto/trace/android/graphics/rect.proto\"\xd8\x01\n\x14LayersTraceFileProto\x12\x14\n\x0cmagic_number\x18\x01 \x01(\x06\x12\x33\n\x05\x65ntry\x18\x02 \x03(\x0b\x32$.perfetto.protos.LayersSnapshotProto\x12)\n!real_to_elapsed_time_offset_nanos\x18\x03 \x01(\x06\"J\n\x0bMagicNumber\x12\x0b\n\x07INVALID\x10\x00\x12\x16\n\x0eMAGIC_NUMBER_L\x10\xcc\xb2\xc9\xa2\x05\x12\x16\n\x0eMAGIC_NUMBER_H\x10\xd2\x82\x8d\xaa\x04\"\x83\x02\n\x13LayersSnapshotProto\x12\x1e\n\x16\x65lapsed_realtime_nanos\x18\x01 \x01(\x10\x12\r\n\x05where\x18\x02 \x01(\t\x12,\n\x06layers\x18\x03 \x01(\x0b\x32\x1c.perfetto.protos.LayersProto\x12\x10\n\x08hwc_blob\x18\x04 \x01(\t\x12\"\n\x1a\x65xcludes_composition_state\x18\x05 \x01(\x08\x12\x16\n\x0emissed_entries\x18\x06 \x01(\r\x12/\n\x08\x64isplays\x18\x07 \x03(\x0b\x32\x1d.perfetto.protos.DisplayProto\x12\x10\n\x08vsync_id\x18\x08 \x01(\x03\":\n\x0bLayersProto\x12+\n\x06layers\x18\x01 \x03(\x0b\x32\x1b.perfetto.protos.LayerProto\"\x89\x02\n\x0c\x44isplayProto\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0blayer_stack\x18\x03 \x01(\r\x12(\n\x04size\x18\x04 \x01(\x0b\x32\x1a.perfetto.protos.SizeProto\x12:\n\x16layer_stack_space_rect\x18\x05 \x01(\x0b\x32\x1a.perfetto.protos.RectProto\x12\x32\n\ttransform\x18\x06 \x01(\x0b\x32\x1f.perfetto.protos.TransformProto\x12\x12\n\nis_virtual\x18\x07 \x01(\x08\x12\r\n\x05\x64pi_x\x18\x08 \x01(\x01\x12\r\n\x05\x64pi_y\x18\t \x01(\x01\"\x8a\x12\n\nLayerProto\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x08\x63hildren\x18\x03 \x03(\x05\x42\x02\x10\x01\x12\x15\n\trelatives\x18\x04 \x03(\x05\x42\x02\x10\x01\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x38\n\x12transparent_region\x18\x06 \x01(\x0b\x32\x1c.perfetto.protos.RegionProto\x12\x34\n\x0evisible_region\x18\x07 \x01(\x0b\x32\x1c.perfetto.protos.RegionProto\x12\x33\n\rdamage_region\x18\x08 \x01(\x0b\x32\x1c.perfetto.protos.RegionProto\x12\x13\n\x0blayer_stack\x18\t \x01(\r\x12\t\n\x01z\x18\n \x01(\x05\x12\x30\n\x08position\x18\x0b \x01(\x0b\x32\x1e.perfetto.protos.PositionProto\x12:\n\x12requested_position\x18\x0c \x01(\x0b\x32\x1e.perfetto.protos.PositionProto\x12(\n\x04size\x18\r \x01(\x0b\x32\x1a.perfetto.protos.SizeProto\x12(\n\x04\x63rop\x18\x0e \x01(\x0b\x32\x1a.perfetto.protos.RectProto\x12\x32\n\nfinal_crop\x18\x0f \x01(\x0b\x32\x1a.perfetto.protos.RectProtoB\x02\x18\x01\x12\x11\n\tis_opaque\x18\x10 \x01(\x08\x12\x12\n\ninvalidate\x18\x11 \x01(\x08\x12\x11\n\tdataspace\x18\x12 \x01(\t\x12\x14\n\x0cpixel_format\x18\x13 \x01(\t\x12*\n\x05\x63olor\x18\x14 \x01(\x0b\x32\x1b.perfetto.protos.ColorProto\x12\x34\n\x0frequested_color\x18\x15 \x01(\x0b\x32\x1b.perfetto.protos.ColorProto\x12\r\n\x05\x66lags\x18\x16 \x01(\r\x12\x32\n\ttransform\x18\x17 \x01(\x0b\x32\x1f.perfetto.protos.TransformProto\x12<\n\x13requested_transform\x18\x18 \x01(\x0b\x32\x1f.perfetto.protos.TransformProto\x12\x0e\n\x06parent\x18\x19 \x01(\x05\x12\x1b\n\x13z_order_relative_of\x18\x1a \x01(\x05\x12\x39\n\ractive_buffer\x18\x1b \x01(\x0b\x32\".perfetto.protos.ActiveBufferProto\x12\x15\n\rqueued_frames\x18\x1c \x01(\x05\x12\x17\n\x0frefresh_pending\x18\x1d \x01(\x08\x12-\n\thwc_frame\x18\x1e \x01(\x0b\x32\x1a.perfetto.protos.RectProto\x12\x31\n\x08hwc_crop\x18\x1f \x01(\x0b\x32\x1f.perfetto.protos.FloatRectProto\x12\x15\n\rhwc_transform\x18  \x01(\x05\x12\x17\n\x0bwindow_type\x18! \x01(\x05\x42\x02\x18\x01\x12\x12\n\x06\x61pp_id\x18\" \x01(\x05\x42\x02\x18\x01\x12\x41\n\x14hwc_composition_type\x18# \x01(\x0e\x32#.perfetto.protos.HwcCompositionType\x12\x14\n\x0cis_protected\x18$ \x01(\x08\x12\x12\n\ncurr_frame\x18% \x01(\x04\x12\x39\n\rbarrier_layer\x18& \x03(\x0b\x32\".perfetto.protos.BarrierLayerProto\x12\x39\n\x10\x62uffer_transform\x18\' \x01(\x0b\x32\x1f.perfetto.protos.TransformProto\x12\x1e\n\x16\x65\x66\x66\x65\x63tive_scaling_mode\x18( \x01(\x05\x12\x15\n\rcorner_radius\x18) \x01(\x02\x12;\n\x08metadata\x18* \x03(\x0b\x32).perfetto.protos.LayerProto.MetadataEntry\x12<\n\x13\x65\x66\x66\x65\x63tive_transform\x18+ \x01(\x0b\x32\x1f.perfetto.protos.TransformProto\x12\x36\n\rsource_bounds\x18, \x01(\x0b\x32\x1f.perfetto.protos.FloatRectProto\x12/\n\x06\x62ounds\x18- \x01(\x0b\x32\x1f.perfetto.protos.FloatRectProto\x12\x36\n\rscreen_bounds\x18. \x01(\x0b\x32\x1f.perfetto.protos.FloatRectProto\x12@\n\x11input_window_info\x18/ \x01(\x0b\x32%.perfetto.protos.InputWindowInfoProto\x12;\n\x12\x63orner_radius_crop\x18\x30 \x01(\x0b\x32\x1f.perfetto.protos.FloatRectProto\x12\x15\n\rshadow_radius\x18\x31 \x01(\x02\x12=\n\x0f\x63olor_transform\x18\x32 \x01(\x0b\x32$.perfetto.protos.ColorTransformProto\x12\x16\n\x0eis_relative_of\x18\x33 \x01(\x08\x12\x1e\n\x16\x62\x61\x63kground_blur_radius\x18\x34 \x01(\x05\x12\x11\n\towner_uid\x18\x35 \x01(\r\x12\x31\n\x0c\x62lur_regions\x18\x36 \x03(\x0b\x32\x1b.perfetto.protos.BlurRegion\x12\x1a\n\x12is_trusted_overlay\x18\x37 \x01(\x08\x12\x1f\n\x17requested_corner_radius\x18\x38 \x01(\x02\x12\x35\n\x11\x64\x65stination_frame\x18\x39 \x01(\x0b\x32\x1a.perfetto.protos.RectProto\x12\x13\n\x0boriginal_id\x18: \x01(\r\x12\x38\n\x0ftrusted_overlay\x18; \x01(\x0e\x32\x1f.perfetto.protos.TrustedOverlay\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"%\n\rPositionProto\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\"J\n\x0e\x46loatRectProto\x12\x0c\n\x04left\x18\x01 \x01(\x02\x12\x0b\n\x03top\x18\x02 \x01(\x02\x12\r\n\x05right\x18\x03 \x01(\x02\x12\x0e\n\x06\x62ottom\x18\x04 \x01(\x02\"a\n\x11\x41\x63tiveBufferProto\x12\r\n\x05width\x18\x01 \x01(\r\x12\x0e\n\x06height\x18\x02 \x01(\r\x12\x0e\n\x06stride\x18\x03 \x01(\r\x12\x0e\n\x06\x66ormat\x18\x04 \x01(\x05\x12\r\n\x05usage\x18\x05 \x01(\x04\"5\n\x11\x42\x61rrierLayerProto\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x14\n\x0c\x66rame_number\x18\x02 \x01(\x04*\xbf\x01\n\x12HwcCompositionType\x12\x18\n\x14HWC_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fHWC_TYPE_CLIENT\x10\x01\x12\x13\n\x0fHWC_TYPE_DEVICE\x10\x02\x12\x18\n\x14HWC_TYPE_SOLID_COLOR\x10\x03\x12\x13\n\x0fHWC_TYPE_CURSOR\x10\x04\x12\x15\n\x11HWC_TYPE_SIDEBAND\x10\x05\x12\x1f\n\x1bHWC_TYPE_DISPLAY_DECORATION\x10\x06')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.android.surfaceflinger_layers_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LAYERPROTO_METADATAENTRY']._loaded_options = None
  _globals['_LAYERPROTO_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_LAYERPROTO'].fields_by_name['children']._loaded_options = None
  _globals['_LAYERPROTO'].fields_by_name['children']._serialized_options = b'\020\001'
  _globals['_LAYERPROTO'].fields_by_name['relatives']._loaded_options = None
  _globals['_LAYERPROTO'].fields_by_name['relatives']._serialized_options = b'\020\001'
  _globals['_LAYERPROTO'].fields_by_name['final_crop']._loaded_options = None
  _globals['_LAYERPROTO'].fields_by_name['final_crop']._serialized_options = b'\030\001'
  _globals['_LAYERPROTO'].fields_by_name['window_type']._loaded_options = None
  _globals['_LAYERPROTO'].fields_by_name['window_type']._serialized_options = b'\030\001'
  _globals['_LAYERPROTO'].fields_by_name['app_id']._loaded_options = None
  _globals['_LAYERPROTO'].fields_by_name['app_id']._serialized_options = b'\030\001'
  _globals['_HWCCOMPOSITIONTYPE']._serialized_start=3584
  _globals['_HWCCOMPOSITIONTYPE']._serialized_end=3775
  _globals['_LAYERSTRACEFILEPROTO']._serialized_start=189
  _globals['_LAYERSTRACEFILEPROTO']._serialized_end=405
  _globals['_LAYERSTRACEFILEPROTO_MAGICNUMBER']._serialized_start=331
  _globals['_LAYERSTRACEFILEPROTO_MAGICNUMBER']._serialized_end=405
  _globals['_LAYERSSNAPSHOTPROTO']._serialized_start=408
  _globals['_LAYERSSNAPSHOTPROTO']._serialized_end=667
  _globals['_LAYERSPROTO']._serialized_start=669
  _globals['_LAYERSPROTO']._serialized_end=727
  _globals['_DISPLAYPROTO']._serialized_start=730
  _globals['_DISPLAYPROTO']._serialized_end=995
  _globals['_LAYERPROTO']._serialized_start=998
  _globals['_LAYERPROTO']._serialized_end=3312
  _globals['_LAYERPROTO_METADATAENTRY']._serialized_start=3265
  _globals['_LAYERPROTO_METADATAENTRY']._serialized_end=3312
  _globals['_POSITIONPROTO']._serialized_start=3314
  _globals['_POSITIONPROTO']._serialized_end=3351
  _globals['_FLOATRECTPROTO']._serialized_start=3353
  _globals['_FLOATRECTPROTO']._serialized_end=3427
  _globals['_ACTIVEBUFFERPROTO']._serialized_start=3429
  _globals['_ACTIVEBUFFERPROTO']._serialized_end=3526
  _globals['_BARRIERLAYERPROTO']._serialized_start=3528
  _globals['_BARRIERLAYERPROTO']._serialized_end=3581
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/common/android_log_constants.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/common/android_log_constants.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2protos/perfetto/common/android_log_constants.proto\x12\x0fperfetto.protos*\x8e\x01\n\x0c\x41ndroidLogId\x12\x0f\n\x0bLID_DEFAULT\x10\x00\x12\r\n\tLID_RADIO\x10\x01\x12\x0e\n\nLID_EVENTS\x10\x02\x12\x0e\n\nLID_SYSTEM\x10\x03\x12\r\n\tLID_CRASH\x10\x04\x12\r\n\tLID_STATS\x10\x05\x12\x10\n\x0cLID_SECURITY\x10\x06\x12\x0e\n\nLID_KERNEL\x10\x07*\x9b\x01\n\x12\x41ndroidLogPriority\x12\x14\n\x10PRIO_UNSPECIFIED\x10\x00\x12\x0f\n\x0bPRIO_UNUSED\x10\x01\x12\x10\n\x0cPRIO_VERBOSE\x10\x02\x12\x0e\n\nPRIO_DEBUG\x10\x03\x12\r\n\tPRIO_INFO\x10\x04\x12\r\n\tPRIO_WARN\x10\x05\x12\x0e\n\nPRIO_ERROR\x10\x06\x12\x0e\n\nPRIO_FATAL\x10\x07')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.common.android_log_constants_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ANDROIDLOGID']._serialized_start=72
  _globals['_ANDROIDLOGID']._serialized_end=214
  _globals['_ANDROIDLOGPRIORITY']._serialized_start=217
  _globals['_ANDROIDLOGPRIORITY']._serialized_end=372
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/config/profiling/heapprofd_config.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/config/profiling/heapprofd_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7protos/perfetto/config/profiling/heapprofd_config.proto\x12\x0fperfetto.protos\"\xcc\x06\n\x0fHeapprofdConfig\x12\x1f\n\x17sampling_interval_bytes\x18\x01 \x01(\x04\x12)\n!adaptive_sampling_shmem_threshold\x18\x18 \x01(\x04\x12\x35\n-adaptive_sampling_max_sampling_interval_bytes\x18\x19 \x01(\x04\x12\x17\n\x0fprocess_cmdline\x18\x02 \x03(\t\x12\x0b\n\x03pid\x18\x04 \x03(\x04\x12\x1b\n\x13target_installed_by\x18\x1a \x03(\t\x12\r\n\x05heaps\x18\x14 \x03(\t\x12\x15\n\rexclude_heaps\x18\x1b \x03(\t\x12\x1a\n\x12stream_allocations\x18\x17 \x01(\x08\x12\x1f\n\x17heap_sampling_intervals\x18\x16 \x03(\x04\x12\x11\n\tall_heaps\x18\x15 \x01(\x08\x12\x0b\n\x03\x61ll\x18\x05 \x01(\x08\x12\x1f\n\x17min_anonymous_memory_kb\x18\x0f \x01(\r\x12\x1f\n\x17max_heapprofd_memory_kb\x18\x10 \x01(\r\x12\x1e\n\x16max_heapprofd_cpu_secs\x18\x11 \x01(\x04\x12\x1a\n\x12skip_symbol_prefix\x18\x07 \x03(\t\x12U\n\x16\x63ontinuous_dump_config\x18\x06 \x01(\x0b\x32\x35.perfetto.protos.HeapprofdConfig.ContinuousDumpConfig\x12\x18\n\x10shmem_size_bytes\x18\x08 \x01(\x04\x12\x14\n\x0c\x62lock_client\x18\t \x01(\x08\x12\x1f\n\x17\x62lock_client_timeout_us\x18\x0e \x01(\r\x12\x12\n\nno_startup\x18\n \x01(\x08\x12\x12\n\nno_running\x18\x0b \x01(\x08\x12\x13\n\x0b\x64ump_at_max\x18\r \x01(\x08\x12\x1d\n\x15\x64isable_fork_teardown\x18\x12 \x01(\x08\x12\x1f\n\x17\x64isable_vfork_detection\x18\x13 \x01(\x08\x1aG\n\x14\x43ontinuousDumpConfig\x12\x15\n\rdump_phase_ms\x18\x05 \x01(\r\x12\x18\n\x10\x64ump_interval_ms\x18\x06 \x01(\rJ\x04\x08\x0c\x10\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.config.profiling.heapprofd_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_HEAPPROFDCONFIG']._serialized_start=77
  _globals['_HEAPPROFDCONFIG']._serialized_end=921
  _globals['_HEAPPROFDCONFIG_CONTINUOUSDUMPCONFIG']._serialized_start=844
  _globals['_HEAPPROFDCONFIG_CONTINUOUSDUMPCONFIG']._serialized_end=915
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/ftrace/virtio_video.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/ftrace/virtio_video.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/protos/perfetto/trace/ftrace/virtio_video.proto\x12\x0fperfetto.protos\"<\n\x19VirtioVideoCmdFtraceEvent\x12\x11\n\tstream_id\x18\x01 \x01(\r\x12\x0c\n\x04type\x18\x02 \x01(\r\"@\n\x1dVirtioVideoCmdDoneFtraceEvent\x12\x11\n\tstream_id\x18\x01 \x01(\r\x12\x0c\n\x04type\x18\x02 \x01(\r\"\xc4\x01\n#VirtioVideoResourceQueueFtraceEvent\x12\x12\n\ndata_size0\x18\x01 \x01(\r\x12\x12\n\ndata_size1\x18\x02 \x01(\r\x12\x12\n\ndata_size2\x18\x03 \x01(\r\x12\x12\n\ndata_size3\x18\x04 \x01(\r\x12\x12\n\nqueue_type\x18\x05 \x01(\r\x12\x13\n\x0bresource_id\x18\x06 \x01(\x05\x12\x11\n\tstream_id\x18\x07 \x01(\x05\x12\x11\n\ttimestamp\x18\x08 \x01(\x04\"\xc8\x01\n\'VirtioVideoResourceQueueDoneFtraceEvent\x12\x12\n\ndata_size0\x18\x01 \x01(\r\x12\x12\n\ndata_size1\x18\x02 \x01(\r\x12\x12\n\ndata_size2\x18\x03 \x01(\r\x12\x12\n\ndata_size3\x18\x04 \x01(\r\x12\x12\n\nqueue_type\x18\x05 \x01(\r\x12\x13\n\x0bresource_id\x18\x06 \x01(\x05\x12\x11\n\tstream_id\x18\x07 \x01(\x05\x12\x11\n\ttimestamp\x18\x08 \x01(\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.ftrace.virtio_video_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_VIRTIOVIDEOCMDFTRACEEVENT']._serialized_start=68
  _globals['_VIRTIOVIDEOCMDFTRACEEVENT']._serialized_end=128
  _globals['_VIRTIOVIDEOCMDDONEFTRACEEVENT']._serialized_start=130
  _globals['_VIRTIOVIDEOCMDDONEFTRACEEVENT']._serialized_end=194
  _globals['_VIRTIOVIDEORESOURCEQUEUEFTRACEEVENT']._serialized_start=197
  _globals['_VIRTIOVIDEORESOURCEQUEUEFTRACEEVENT']._serialized_end=393
  _globals['_VIRTIOVIDEORESOURCEQUEUEDONEFTRACEEVENT']._serialized_start=396
  _globals['_VIRTIOVIDEORESOURCEQUEUEDONEFTRACEEVENT']._serialized_end=596
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/ftrace/cgroup.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/ftrace/cgroup.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)protos/perfetto/trace/ftrace/cgroup.proto\x12\x0fperfetto.protos\"\x8e\x01\n\x1b\x43groupAttachTaskFtraceEvent\x12\x10\n\x08\x64st_root\x18\x01 \x01(\x05\x12\x0e\n\x06\x64st_id\x18\x02 \x01(\x05\x12\x0b\n\x03pid\x18\x03 \x01(\x05\x12\x0c\n\x04\x63omm\x18\x04 \x01(\t\x12\r\n\x05\x63name\x18\x05 \x01(\t\x12\x11\n\tdst_level\x18\x06 \x01(\x05\x12\x10\n\x08\x64st_path\x18\x07 \x01(\t\"^\n\x16\x43groupMkdirFtraceEvent\x12\x0c\n\x04root\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\x05\x12\r\n\x05\x63name\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\x05\x12\x0c\n\x04path\x18\x05 \x01(\t\"G\n\x18\x43groupRemountFtraceEvent\x12\x0c\n\x04root\x18\x01 \x01(\x05\x12\x0f\n\x07ss_mask\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\"^\n\x16\x43groupRmdirFtraceEvent\x12\x0c\n\x04root\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\x05\x12\r\n\x05\x63name\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\x05\x12\x0c\n\x04path\x18\x05 \x01(\t\"\x91\x01\n\x1e\x43groupTransferTasksFtraceEvent\x12\x10\n\x08\x64st_root\x18\x01 \x01(\x05\x12\x0e\n\x06\x64st_id\x18\x02 \x01(\x05\x12\x0b\n\x03pid\x18\x03 \x01(\x05\x12\x0c\n\x04\x63omm\x18\x04 \x01(\t\x12\r\n\x05\x63name\x18\x05 \x01(\t\x12\x11\n\tdst_level\x18\x06 \x01(\x05\x12\x10\n\x08\x64st_path\x18\x07 \x01(\t\"K\n\x1c\x43groupDestroyRootFtraceEvent\x12\x0c\n\x04root\x18\x01 \x01(\x05\x12\x0f\n\x07ss_mask\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\"`\n\x18\x43groupReleaseFtraceEvent\x12\x0c\n\x04root\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\x05\x12\r\n\x05\x63name\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\x05\x12\x0c\n\x04path\x18\x05 \x01(\t\"_\n\x17\x43groupRenameFtraceEvent\x12\x0c\n\x04root\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\x05\x12\r\n\x05\x63name\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\x05\x12\x0c\n\x04path\x18\x05 \x01(\t\"I\n\x1a\x43groupSetupRootFtraceEvent\x12\x0c\n\x04root\x18\x01 \x01(\x05\x12\x0f\n\x07ss_mask\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.ftrace.cgroup_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CGROUPATTACHTASKFTRACEEVENT']._serialized_start=63
  _globals['_CGROUPATTACHTASKFTRACEEVENT']._serialized_end=205
  _globals['_CGROUPMKDIRFTRACEEVENT']._serialized_start=207
  _globals['_CGROUPMKDIRFTRACEEVENT']._serialized_end=301
  _globals['_CGROUPREMOUNTFTRACEEVENT']._serialized_start=303
  _globals['_CGROUPREMOUNTFTRACEEVENT']._serialized_end=374
  _globals['_CGROUPRMDIRFTRACEEVENT']._serialized_start=376
  _globals['_CGROUPRMDIRFTRACEEVENT']._serialized_end=470
  _globals['_CGROUPTRANSFERTASKSFTRACEEVENT']._serialized_start=473
  _globals['_CGROUPTRANSFERTASKSFTRACEEVENT']._serialized_end=618
  _globals['_CGROUPDESTROYROOTFTRACEEVENT']._serialized_start=620
  _globals['_CGROUPDESTROYROOTFTRACEEVENT']._serialized_end=695
  _globals['_CGROUPRELEASEFTRACEEVENT']._serialized_start=697
  _globals['_CGROUPRELEASEFTRACEEVENT']._serialized_end=793
  _globals['_CGROUPRENAMEFTRACEEVENT']._serialized_start=795
  _globals['_CGROUPRENAMEFTRACEEVENT']._serialized_end=890
  _globals['_CGROUPSETUPROOTFTRACEEVENT']._serialized_start=892
  _globals['_CGROUPSETUPROOTFTRACEEVENT']._serialized_end=965
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/ps/process_tree.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/ps/process_tree.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+protos/perfetto/trace/ps/process_tree.proto\x12\x0fperfetto.protos\"\xda\x02\n\x0bProcessTree\x12\x37\n\tprocesses\x18\x01 \x03(\x0b\x32$.perfetto.protos.ProcessTree.Process\x12\x34\n\x07threads\x18\x02 \x03(\x0b\x32#.perfetto.protos.ProcessTree.Thread\x12 \n\x18\x63ollection_end_timestamp\x18\x03 \x01(\x04\x1a@\n\x06Thread\x12\x0b\n\x03tid\x18\x01 \x01(\x05\x12\x0c\n\x04tgid\x18\x03 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05nstid\x18\x04 \x03(\x05\x1ax\n\x07Process\x12\x0b\n\x03pid\x18\x01 \x01(\x05\x12\x0c\n\x04ppid\x18\x02 \x01(\x05\x12\x0f\n\x07\x63mdline\x18\x03 \x03(\t\x12\x0b\n\x03uid\x18\x05 \x01(\x05\x12\r\n\x05nspid\x18\x06 \x03(\x05\x12\x1f\n\x17process_start_from_boot\x18\x07 \x01(\x04J\x04\x08\x04\x10\x05')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.ps.process_tree_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PROCESSTREE']._serialized_start=65
  _globals['_PROCESSTREE']._serialized_end=411
  _globals['_PROCESSTREE_THREAD']._serialized_start=225
  _globals['_PROCESSTREE_THREAD']._serialized_end=289
  _globals['_PROCESSTREE_PROCESS']._serialized_start=291
  _globals['_PROCESSTREE_PROCESS']._serialized_end=411
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/chrome/chrome_benchmark_metadata.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/chrome/chrome_benchmark_metadata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<protos/perfetto/trace/chrome/chrome_benchmark_metadata.proto\x12\x0fperfetto.protos\"\xf2\x01\n\x17\x43hromeBenchmarkMetadata\x12\x1f\n\x17\x62\x65nchmark_start_time_us\x18\x01 \x01(\x03\x12\x19\n\x11story_run_time_us\x18\x02 \x01(\x03\x12\x16\n\x0e\x62\x65nchmark_name\x18\x03 \x01(\t\x12\x1d\n\x15\x62\x65nchmark_description\x18\x04 \x01(\t\x12\r\n\x05label\x18\x05 \x01(\t\x12\x12\n\nstory_name\x18\x06 \x01(\t\x12\x12\n\nstory_tags\x18\x07 \x03(\t\x12\x17\n\x0fstory_run_index\x18\x08 \x01(\x05\x12\x14\n\x0chad_failures\x18\t \x01(\x08')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.chrome.chrome_benchmark_metadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CHROMEBENCHMARKMETADATA']._serialized_start=82
  _globals['_CHROMEBENCHMARKMETADATA']._serialized_end=324
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/profiling/profile_common.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/profiling/profile_common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4protos/perfetto/trace/profiling/profile_common.proto\x12\x0fperfetto.protos\"*\n\x0eInternedString\x12\x0b\n\x03iid\x18\x01 \x01(\x04\x12\x0b\n\x03str\x18\x02 \x01(\x0c\"n\n\x14ProfiledFrameSymbols\x12\x11\n\tframe_iid\x18\x01 \x01(\x04\x12\x18\n\x10\x66unction_name_id\x18\x02 \x03(\x04\x12\x14\n\x0c\x66ile_name_id\x18\x03 \x03(\x04\x12\x13\n\x0bline_number\x18\x04 \x03(\r\"L\n\x04Line\x12\x15\n\rfunction_name\x18\x01 \x01(\t\x12\x18\n\x10source_file_name\x18\x02 \x01(\t\x12\x13\n\x0bline_number\x18\x03 \x01(\r\"G\n\x0e\x41\x64\x64ressSymbols\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x04\x12$\n\x05lines\x18\x02 \x03(\x0b\x32\x15.perfetto.protos.Line\"i\n\rModuleSymbols\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x38\n\x0f\x61\x64\x64ress_symbols\x18\x03 \x03(\x0b\x32\x1f.perfetto.protos.AddressSymbols\"\x9c\x01\n\x07Mapping\x12\x0b\n\x03iid\x18\x01 \x01(\x04\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\x04\x12\x14\n\x0c\x65xact_offset\x18\x08 \x01(\x04\x12\x14\n\x0cstart_offset\x18\x03 \x01(\x04\x12\r\n\x05start\x18\x04 \x01(\x04\x12\x0b\n\x03\x65nd\x18\x05 \x01(\x04\x12\x11\n\tload_bias\x18\x06 \x01(\x04\x12\x17\n\x0fpath_string_ids\x18\x07 \x03(\x04\"R\n\x05\x46rame\x12\x0b\n\x03iid\x18\x01 \x01(\x04\x12\x18\n\x10\x66unction_name_id\x18\x02 \x01(\x04\x12\x12\n\nmapping_id\x18\x03 \x01(\x04\x12\x0e\n\x06rel_pc\x18\x04 \x01(\x04\"+\n\tCallstack\x12\x0b\n\x03iid\x18\x01 \x01(\x04\x12\x11\n\tframe_ids\x18\x02 \x03(\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.profiling.profile_common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_INTERNEDSTRING']._serialized_start=73
  _globals['_INTERNEDSTRING']._serialized_end=115
  _globals['_PROFILEDFRAMESYMBOLS']._serialized_start=117
  _globals['_PROFILEDFRAMESYMBOLS']._serialized_end=227
  _globals['_LINE']._serialized_start=229
  _globals['_LINE']._serialized_end=305
  _globals['_ADDRESSSYMBOLS']._serialized_start=307
  _globals['_ADDRESSSYMBOLS']._serialized_end=378
  _globals['_MODULESYMBOLS']._serialized_start=380
  _globals['_MODULESYMBOLS']._serialized_end=485
  _globals['_MAPPING']._serialized_start=488
  _globals['_MAPPING']._serialized_end=644
  _globals['_FRAME']._serialized_start=646
  _globals['_FRAME']._serialized_end=728
  _globals['_CALLSTACK']._serialized_start=730
  _globals['_CALLSTACK']._serialized_end=773
# @@protoc_insertion_point(module_scope)
